# Tagger

Tagger is a scripting language for Discord bot. It can be used from tag command to user automation moderation. It is simple but powerful. Users cannot run code that can harm your bot. You can add new function and class to it in a simple way.

# Example

```tagger
{do
    {msg.set("React with :heart: to claim this present")}
    {msg.wait_for_reaction(":heart:")}
    {msg.set("Just kidding there is no present")}
}
```
Check example for more

# Install

## PIP
```
pip install taggerscript
```

## Poetry
```
poetry add taggerscript
```

## git clone
```
git clone https://github.com/najis-poop/TaggerScript
```

# Documentation

coming soon

# Feedback

Tagger still in development. Any bug should be reported quickly by creating issue in github issue.